summaryrefslogtreecommitdiffstats
path: root/kmail
diff options
context:
space:
mode:
Diffstat (limited to 'kmail')
-rw-r--r--kmail/CMakeLists.txt6
-rw-r--r--kmail/Mainpage.dox2
-rw-r--r--kmail/Makefile.am4
-rw-r--r--kmail/encodingdetector.cpp2
-rw-r--r--kmail/encodingdetector_ja_p.h6
-rw-r--r--kmail/headerstyle.cpp2
-rw-r--r--kmail/kmail_part.cpp4
-rw-r--r--kmail/kmail_part.h10
-rw-r--r--kmail/kmcommands.cpp4
-rw-r--r--kmail/kmcomposewin.cpp4
-rw-r--r--kmail/kmedit.cpp4
-rw-r--r--kmail/kmedit.h2
-rw-r--r--kmail/kmheaders.cpp2
-rw-r--r--kmail/kmkernel.cpp2
-rw-r--r--kmail/kmkernel.h2
-rw-r--r--kmail/kmmessage.cpp2
-rw-r--r--kmail/kmmsgdict.cpp2
-rw-r--r--kmail/kmreaderwin.cpp8
-rw-r--r--kmail/kmtransport.cpp4
-rw-r--r--kmail/networkaccount.cpp2
-rw-r--r--kmail/objecttreeparser.cpp2
-rw-r--r--kmail/regexplineedit.cpp2
-rw-r--r--kmail/searchwindow.cpp2
-rw-r--r--kmail/snippetwidget.h4
-rw-r--r--kmail/tdehtmlparthtmlwriter.cpp (renamed from kmail/khtmlparthtmlwriter.cpp)10
-rw-r--r--kmail/tdehtmlparthtmlwriter.h (renamed from kmail/khtmlparthtmlwriter.h)2
-rw-r--r--kmail/tdemdict.cpp (renamed from kmail/kmdict.cpp)2
-rw-r--r--kmail/tdemdict.h (renamed from kmail/kmdict.h)0
-rw-r--r--kmail/tests/Makefile.am24
-rw-r--r--kmail/tests/messagedicttests.cpp6
-rw-r--r--kmail/tests/messagedicttests.h2
-rw-r--r--kmail/tests/mimelibtests.cpp8
-rw-r--r--kmail/tests/mimelibtests.h2
-rw-r--r--kmail/tests/storagelayermodule.cpp6
-rw-r--r--kmail/tests/utiltests.cpp6
-rw-r--r--kmail/tests/utiltests.h2
-rw-r--r--kmail/urlhandlermanager.cpp4
37 files changed, 79 insertions, 79 deletions
diff --git a/kmail/CMakeLists.txt b/kmail/CMakeLists.txt
index 7e1ac19e..ebd61ef8 100644
--- a/kmail/CMakeLists.txt
+++ b/kmail/CMakeLists.txt
@@ -140,7 +140,7 @@ set( ${target}_SRCS
kmcomposewin.cpp kmfolder.cpp kmmsgpartdlg.cpp kmreaderwin.cpp htmlstatusbar.cpp
kmgroupware.cpp folderstorage.cpp listjob.cpp csshelper.cpp klistboxdialog.cpp
kmmsginfo.cpp actionscheduler.cpp messageproperty.cpp accountmanager.cpp kmacctfolder.cpp
- kmdict.cpp kmsystemtray.cpp kmacctlocal.cpp kmfolderdir.cpp kmfoldermgr.cpp
+ tdemdict.cpp kmsystemtray.cpp kmacctlocal.cpp kmfolderdir.cpp kmfoldermgr.cpp
kmfoldernode.cpp kmsender.cpp kmacctseldlg.cpp kmfiltermgr.cpp kmfilterdlg.cpp
filterimporterexporter.cpp kmsearchpatternedit.cpp encodingdetector.cpp encodingdetector_ja.cpp
kmfilteraction.cpp kmsearchpattern.cpp kmfolderimap.cpp kmfolderseldlg.cpp kmfilter.cpp
@@ -151,7 +151,7 @@ set( ${target}_SRCS
kmkernel.cpp accountdialog.cpp searchwindow.cpp vcardviewer.cpp vacationdialog.cpp
vacation.cpp sievedebugdialog.cpp sieveconfig.cpp sievejob.cpp kmpopheaders.cpp
kmpopfiltercnfrmdlg.cpp kmmimeparttree.cpp mailinglist-magic.cpp kmacctmaildir.cpp
- headerstyle.cpp headerstrategy.cpp khtmlparthtmlwriter.cpp filehtmlwriter.cpp
+ headerstyle.cpp headerstrategy.cpp tdehtmlparthtmlwriter.cpp filehtmlwriter.cpp
teehtmlwriter.cpp mailcomposerIface.skel objecttreeparser.cpp objecttreeparser_p.cpp
attachmentcollector.cpp bodypartformatterfactory.cpp bodypartformatter.cpp partNode.cpp
mailsourceviewer.cpp kmcommands.cpp kmreadermainwin.cpp kmstartup.cpp kmmainwidget.cpp
@@ -191,7 +191,7 @@ tde_add_library( ${target} SHARED AUTOMOC
SOURCES ${${target}_SRCS}
LINK
emailfunctions-static kmime-shared kpgp-shared tdepim-shared kpimidentities-shared
- mimelib-shared ksieve-shared khtml-shared ${INDEX_LIBRARY}
+ mimelib-shared ksieve-shared tdehtml-shared ${INDEX_LIBRARY}
DESTINATION ${LIB_INSTALL_DIR}
)
diff --git a/kmail/Mainpage.dox b/kmail/Mainpage.dox
index 927acc7e..42201dad 100644
--- a/kmail/Mainpage.dox
+++ b/kmail/Mainpage.dox
@@ -42,7 +42,7 @@ access to all the core KMail functionality.
FIXME this has moved to libkpimidentities, right?
-Files: identity*, kmidentity.{h,cpp}, configuredialog.cpp,
+Files: identity*, tdemidentity.{h,cpp}, configuredialog.cpp,
signatureconfigurator.{h,cpp}
Contact Marc Mutz <mutz@kde.org> on questions...
diff --git a/kmail/Makefile.am b/kmail/Makefile.am
index 9dd1dc0d..6fcc46de 100644
--- a/kmail/Makefile.am
+++ b/kmail/Makefile.am
@@ -65,7 +65,7 @@ libkmailprivate_la_SOURCES = kmmessage.cpp kmmainwin.cpp configuredialog.cpp \
csshelper.cpp klistboxdialog.cpp \
actionscheduler.cpp messageproperty.cpp \
kmmsgpart.cpp kmmsginfo.cpp \
- accountmanager.cpp kmacctfolder.cpp kmdict.cpp \
+ accountmanager.cpp kmacctfolder.cpp tdemdict.cpp \
kmsystemtray.cpp kmacctlocal.cpp kmfolderdir.cpp \
kmfoldermgr.cpp kmfoldernode.cpp kmsender.cpp \
kmacctseldlg.cpp kmfiltermgr.cpp kmsearchpatternedit.cpp \
@@ -88,7 +88,7 @@ libkmailprivate_la_SOURCES = kmmessage.cpp kmmainwin.cpp configuredialog.cpp \
kmmimeparttree.cpp \
mailinglist-magic.cpp kmacctmaildir.cpp \
attachmentstrategy.cpp \
- headerstrategy.cpp headerstyle.cpp khtmlparthtmlwriter.cpp \
+ headerstrategy.cpp headerstyle.cpp tdehtmlparthtmlwriter.cpp \
filehtmlwriter.cpp teehtmlwriter.cpp \
mailcomposerIface.skel objecttreeparser.cpp \
objecttreeparser_p.cpp \
diff --git a/kmail/encodingdetector.cpp b/kmail/encodingdetector.cpp
index d5ffd5dc..01a60d88 100644
--- a/kmail/encodingdetector.cpp
+++ b/kmail/encodingdetector.cpp
@@ -1135,7 +1135,7 @@ bool EncodingDetector::analyze(const char *data, int len)
case EncodingDetector::WesternEuropean:
if (setEncoding(automaticDetectionForWesternEuropean( (const unsigned char*) data, len ), AutoDetectedEncoding))
return true;
- else if (d->m_defaultCodec->mibEnum()==MibLatin1) //detection for khtml
+ else if (d->m_defaultCodec->mibEnum()==MibLatin1) //detection for tdehtml
{
return setEncoding("iso-8859-15",AutoDetectedEncoding);
}
diff --git a/kmail/encodingdetector_ja_p.h b/kmail/encodingdetector_ja_p.h
index dac255d5..26eaa523 100644
--- a/kmail/encodingdetector_ja_p.h
+++ b/kmail/encodingdetector_ja_p.h
@@ -42,7 +42,7 @@
#ifdef TQ_WS_WIN
#undef UNICODE
#endif
-namespace khtml {
+namespace tdehtml {
class guess_arc {
public:
unsigned int next; /* next state */
@@ -50,7 +50,7 @@ namespace khtml {
};
}
-using namespace khtml;
+using namespace tdehtml;
typedef signed char dfa_table[256];
@@ -62,7 +62,7 @@ extern guess_arc guess_sjis_ar[6];
extern const dfa_table guess_utf8_st[];
extern guess_arc guess_utf8_ar[11];
-namespace khtml {
+namespace tdehtml {
class guess_dfa {
public:
diff --git a/kmail/headerstyle.cpp b/kmail/headerstyle.cpp
index 5c4108ee..1bf75f09 100644
--- a/kmail/headerstyle.cpp
+++ b/kmail/headerstyle.cpp
@@ -53,7 +53,7 @@ using namespace KPIM;
#include <kdebug.h>
#include <klocale.h>
#include <kglobal.h>
-#include <kimproxy.h>
+#include <tdeimproxy.h>
#include <kabc/stdaddressbook.h>
#include <kabc/addresseelist.h>
#include <kmdcodec.h>
diff --git a/kmail/kmail_part.cpp b/kmail/kmail_part.cpp
index 1f42a82a..b7857493 100644
--- a/kmail/kmail_part.cpp
+++ b/kmail/kmail_part.cpp
@@ -44,8 +44,8 @@ using KMail::AccountManager;
using KRecentAddress::RecentAddresses;
#include <kapplication.h>
-#include <kparts/mainwindow.h>
-#include <kparts/genericfactory.h>
+#include <tdeparts/mainwindow.h>
+#include <tdeparts/genericfactory.h>
#include <knotifyclient.h>
#include <dcopclient.h>
#include <kiconloader.h>
diff --git a/kmail/kmail_part.h b/kmail/kmail_part.h
index dd5d261a..46f08f68 100644
--- a/kmail/kmail_part.h
+++ b/kmail/kmail_part.h
@@ -28,11 +28,11 @@
#include "kmailpartIface.h"
#include <tdeversion.h>
-#include <kparts/browserextension.h>
-#include <kparts/statusbarextension.h>
-#include <kparts/factory.h>
-#include <kparts/event.h>
-#include <kparts/part.h>
+#include <tdeparts/browserextension.h>
+#include <tdeparts/statusbarextension.h>
+#include <tdeparts/factory.h>
+#include <tdeparts/event.h>
+#include <tdeparts/part.h>
#include <tqwidget.h>
#include <tdepimmacros.h>
diff --git a/kmail/kmcommands.cpp b/kmail/kmcommands.cpp
index 9c1d25f9..023c887d 100644
--- a/kmail/kmcommands.cpp
+++ b/kmail/kmcommands.cpp
@@ -67,13 +67,13 @@
#include <kdirselectdialog.h>
#include <klocale.h>
#include <kmessagebox.h>
-#include <kparts/browserextension.h>
+#include <tdeparts/browserextension.h>
#include <kprogress.h>
#include <krun.h>
#include <kbookmarkmanager.h>
#include <kstandarddirs.h>
#include <ktempfile.h>
-#include <kimproxy.h>
+#include <tdeimproxy.h>
#include <kuserprofile.h>
// KIO headers
#include <kio/job.h>
diff --git a/kmail/kmcomposewin.cpp b/kmail/kmcomposewin.cpp
index 0857ae2b..d635b647 100644
--- a/kmail/kmcomposewin.cpp
+++ b/kmail/kmcomposewin.cpp
@@ -109,8 +109,8 @@ using KRecentAddress::RecentAddresses;
#include "globalsettings.h"
#include "replyphrases.h"
-#include <kspell.h>
-#include <kspelldlg.h>
+#include <tdespell.h>
+#include <tdespelldlg.h>
#include <spellingfilter.h>
#include <ksyntaxhighlighter.h>
#include <kcolordialog.h>
diff --git a/kmail/kmedit.cpp b/kmail/kmedit.cpp
index 044e0541..8301a12c 100644
--- a/kmail/kmedit.cpp
+++ b/kmail/kmedit.cpp
@@ -38,8 +38,8 @@ using KPIM::MailListDrag;
#include "globalsettings.h"
#include "replyphrases.h"
-#include <kspell.h>
-#include <kspelldlg.h>
+#include <tdespell.h>
+#include <tdespelldlg.h>
#include <spellingfilter.h>
#include <ksyntaxhighlighter.h>
diff --git a/kmail/kmedit.h b/kmail/kmedit.h
index 24458cd3..f545a136 100644
--- a/kmail/kmedit.h
+++ b/kmail/kmedit.h
@@ -7,7 +7,7 @@
#include <tdeversion.h>
#include <keditcl.h>
-#include <kspell.h>
+#include <tdespell.h>
#include <ksyntaxhighlighter.h>
#include <tqmap.h>
#include <tqstringlist.h>
diff --git a/kmail/kmheaders.cpp b/kmail/kmheaders.cpp
index 8e142c91..2ed379c9 100644
--- a/kmail/kmheaders.cpp
+++ b/kmail/kmheaders.cpp
@@ -2401,7 +2401,7 @@ void KMHeaders::contentsMouseMoveEvent( TQMouseEvent* e )
if( count == 1 )
pixmap = TQPixmap( DesktopIcon("message", KIcon::SizeSmall) );
else
- pixmap = TQPixmap( DesktopIcon("kmultiple", KIcon::SizeSmall) );
+ pixmap = TQPixmap( DesktopIcon("tdemultiple", KIcon::SizeSmall) );
// Calculate hotspot (as in Konqueror)
if( !pixmap.isNull() ) {
diff --git a/kmail/kmkernel.cpp b/kmail/kmkernel.cpp
index e5dd7072..354fe768 100644
--- a/kmail/kmkernel.cpp
+++ b/kmail/kmkernel.cpp
@@ -69,7 +69,7 @@ using KMail::FolderIface;
#include <kpgp.h>
#include <kdebug.h>
#include <kio/netaccess.h>
-#include <kwallet.h>
+#include <tdewallet.h>
using KWallet::Wallet;
#include "actionscheduler.h"
diff --git a/kmail/kmkernel.h b/kmail/kmkernel.h
index fb01231b..9d2b5070 100644
--- a/kmail/kmkernel.h
+++ b/kmail/kmkernel.h
@@ -11,7 +11,7 @@
#include <kconfig.h>
#include <tdeversion.h>
-#include <kimproxy.h>
+#include <tdeimproxy.h>
#include <tdepimmacros.h>
#include "kmailIface.h"
diff --git a/kmail/kmmessage.cpp b/kmail/kmmessage.cpp
index 20f9ce4c..aabc14bc 100644
--- a/kmail/kmmessage.cpp
+++ b/kmail/kmmessage.cpp
@@ -38,7 +38,7 @@ using KMail::HeaderStrategy;
#include <kglobalsettings.h>
#include <kdebug.h>
#include <kconfig.h>
-#include <khtml_part.h>
+#include <tdehtml_part.h>
#include <kuser.h>
#include <kidna.h>
#include <kasciistricmp.h>
diff --git a/kmail/kmmsgdict.cpp b/kmail/kmmsgdict.cpp
index 729a3663..fdf2e1b2 100644
--- a/kmail/kmmsgdict.cpp
+++ b/kmail/kmmsgdict.cpp
@@ -4,7 +4,7 @@
#include "kmfolderindex.h"
#include "kmfolder.h"
#include "kmmsgdict.h"
-#include "kmdict.h"
+#include "tdemdict.h"
#include "globalsettings.h"
#include "folderstorage.h"
diff --git a/kmail/kmreaderwin.cpp b/kmail/kmreaderwin.cpp
index 2ce6c862..0568035b 100644
--- a/kmail/kmreaderwin.cpp
+++ b/kmail/kmreaderwin.cpp
@@ -37,7 +37,7 @@ using KMail::AttachmentStrategy;
using KMail::HeaderStrategy;
#include "headerstyle.h"
using KMail::HeaderStyle;
-#include "khtmlparthtmlwriter.h"
+#include "tdehtmlparthtmlwriter.h"
using KMail::HtmlWriter;
using KMail::KHtmlPartHtmlWriter;
#include "htmlstatusbar.h"
@@ -80,9 +80,9 @@ using KMail::TeeHtmlWriter;
#include <kabc/addressee.h>
#include <kabc/vcardconverter.h>
-// khtml headers
-#include <khtml_part.h>
-#include <khtmlview.h> // So that we can get rid of the frames
+// tdehtml headers
+#include <tdehtml_part.h>
+#include <tdehtmlview.h> // So that we can get rid of the frames
#include <dom/html_element.h>
#include <dom/html_block.h>
#include <dom/html_document.h>
diff --git a/kmail/kmtransport.cpp b/kmail/kmtransport.cpp
index e17fdaf0..2092376f 100644
--- a/kmail/kmtransport.cpp
+++ b/kmail/kmtransport.cpp
@@ -38,7 +38,7 @@
#include <kmessagebox.h>
#include <kseparator.h>
#include <kdebug.h>
-#include <kwallet.h>
+#include <tdewallet.h>
using KWallet::Wallet;
#include <kprotocolinfo.h>
@@ -87,7 +87,7 @@ void KMTransportInfo::readConfig(int id)
return;
if ( !mPasswd.isEmpty() ) {
- // migration to kwallet if available
+ // migration to tdewallet if available
if ( Wallet::isEnabled() ) {
config->deleteEntry( "pass" );
mPasswdDirty = true;
diff --git a/kmail/networkaccount.cpp b/kmail/networkaccount.cpp
index e0b68274..62581bf9 100644
--- a/kmail/networkaccount.cpp
+++ b/kmail/networkaccount.cpp
@@ -37,7 +37,7 @@
#include <klocale.h>
#include <kmessagebox.h>
#include <kdebug.h>
-#include <kwallet.h>
+#include <tdewallet.h>
using TDEIO::MetaData;
using KWallet::Wallet;
diff --git a/kmail/objecttreeparser.cpp b/kmail/objecttreeparser.cpp
index 9c8c673a..6ea48bf0 100644
--- a/kmail/objecttreeparser.cpp
+++ b/kmail/objecttreeparser.cpp
@@ -89,7 +89,7 @@
#include <klocale.h>
#include <kmimetype.h>
#include <kglobal.h>
-#include <khtml_part.h>
+#include <tdehtml_part.h>
#include <ktempfile.h>
#include <kstandarddirs.h>
#include <kapplication.h>
diff --git a/kmail/regexplineedit.cpp b/kmail/regexplineedit.cpp
index 3d292182..a6d86ec3 100644
--- a/kmail/regexplineedit.cpp
+++ b/kmail/regexplineedit.cpp
@@ -38,7 +38,7 @@
#include <klocale.h>
#include <klineedit.h>
-#include <kparts/componentfactory.h>
+#include <tdeparts/componentfactory.h>
#include <kregexpeditorinterface.h>
#include <kdialog.h>
diff --git a/kmail/searchwindow.cpp b/kmail/searchwindow.cpp
index de5e2d7e..15bf5f07 100644
--- a/kmail/searchwindow.cpp
+++ b/kmail/searchwindow.cpp
@@ -95,7 +95,7 @@ class MatchListView : public KListView
if( mailList.count() == 1 )
pixmap = TQPixmap( DesktopIcon("message", KIcon::SizeSmall) );
else
- pixmap = TQPixmap( DesktopIcon("kmultiple", KIcon::SizeSmall) );
+ pixmap = TQPixmap( DesktopIcon("tdemultiple", KIcon::SizeSmall) );
d->setPixmap( pixmap );
return d;
diff --git a/kmail/snippetwidget.h b/kmail/snippetwidget.h
index 18573c38..88a96719 100644
--- a/kmail/snippetwidget.h
+++ b/kmail/snippetwidget.h
@@ -19,8 +19,8 @@
#include <tqtooltip.h>
#include <tqrect.h>
-#include <ktexteditor/editinterface.h>
-#include <ktexteditor/view.h>
+#include <tdetexteditor/editinterface.h>
+#include <tdetexteditor/view.h>
#include "snippetconfig.h"
class KDevProject;
diff --git a/kmail/khtmlparthtmlwriter.cpp b/kmail/tdehtmlparthtmlwriter.cpp
index 3c8ee388..7321e128 100644
--- a/kmail/khtmlparthtmlwriter.cpp
+++ b/kmail/tdehtmlparthtmlwriter.cpp
@@ -1,5 +1,5 @@
/* -*- c++ -*-
- khtmlparthtmlwriter.cpp
+ tdehtmlparthtmlwriter.cpp
This file is part of KMail, the KDE mail client.
Copyright (c) 2003 Marc Mutz <mutz@kde.org>
@@ -31,11 +31,11 @@
#include <config.h>
-#include "khtmlparthtmlwriter.h"
+#include "tdehtmlparthtmlwriter.h"
#include <kdebug.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
#include <dom/dom_string.h>
#include <dom/html_document.h>
@@ -151,4 +151,4 @@ namespace KMail {
} // namespace KMail
-#include "khtmlparthtmlwriter.moc"
+#include "tdehtmlparthtmlwriter.moc"
diff --git a/kmail/khtmlparthtmlwriter.h b/kmail/tdehtmlparthtmlwriter.h
index 52fad112..52f16fd4 100644
--- a/kmail/khtmlparthtmlwriter.h
+++ b/kmail/tdehtmlparthtmlwriter.h
@@ -1,5 +1,5 @@
/* -*- c++ -*-
- khtmlparthtmlwriter.h
+ tdehtmlparthtmlwriter.h
This file is part of KMail, the KDE mail client.
Copyright (c) 2003 Marc Mutz <mutz@kde.org>
diff --git a/kmail/kmdict.cpp b/kmail/tdemdict.cpp
index 0ad9367b..a1c73e6d 100644
--- a/kmail/kmdict.cpp
+++ b/kmail/tdemdict.cpp
@@ -5,7 +5,7 @@
#include <config.h>
#endif
-#include "kmdict.h"
+#include "tdemdict.h"
#include "kmglobal.h"
#include <kdebug.h>
diff --git a/kmail/kmdict.h b/kmail/tdemdict.h
index 6cbbefd5..6cbbefd5 100644
--- a/kmail/kmdict.h
+++ b/kmail/tdemdict.h
diff --git a/kmail/tests/Makefile.am b/kmail/tests/Makefile.am
index 2d492283..c07ad623 100644
--- a/kmail/tests/Makefile.am
+++ b/kmail/tests/Makefile.am
@@ -2,22 +2,22 @@ INCLUDES = -I$(top_srcdir)/kmail -I$(top_srcdir)/mimelib $(all_includes)
AM_CPPFLAGS = -DTDESRCDIR=\"$(srcdir)\"
METASOURCES = AUTO
-check_LTLIBRARIES = kunittest_storagelayermodule.la \
- kunittest_utilmodule.la \
- kunittest_mimelibmodule.la
+check_LTLIBRARIES = tdeunittest_storagelayermodule.la \
+ tdeunittest_utilmodule.la \
+ tdeunittest_mimelibmodule.la
-kunittest_storagelayermodule_la_SOURCES = storagelayermodule.cpp messagedicttests.cpp ../kmdict.cpp
-kunittest_storagelayermodule_la_LIBADD = -lkunittest
-kunittest_utilmodule_la_SOURCES = utiltests.cpp ../util.cpp
-kunittest_utilmodule_la_LIBADD = -lkunittest ../../mimelib/libmimelib.la
-kunittest_mimelibmodule_la_SOURCES = mimelibtests.cpp ../util.cpp
-kunittest_mimelibmodule_la_LIBADD = -lkunittest ../../mimelib/libmimelib.la
+tdeunittest_storagelayermodule_la_SOURCES = storagelayermodule.cpp messagedicttests.cpp ../tdemdict.cpp
+tdeunittest_storagelayermodule_la_LIBADD = -ltdeunittest
+tdeunittest_utilmodule_la_SOURCES = utiltests.cpp ../util.cpp
+tdeunittest_utilmodule_la_LIBADD = -ltdeunittest ../../mimelib/libmimelib.la
+tdeunittest_mimelibmodule_la_SOURCES = mimelibtests.cpp ../util.cpp
+tdeunittest_mimelibmodule_la_LIBADD = -ltdeunittest ../../mimelib/libmimelib.la
-#LIBADD = -lkunittest
+#LIBADD = -ltdeunittest
AM_LDFLAGS = -module $(KDE_CHECK_PLUGIN) $(all_libraries)
check-local:
- kunittestmodrunner
+ tdeunittestmodrunner
guicheck:
- kunittestguimodrunner
+ tdeunittestguimodrunner
diff --git a/kmail/tests/messagedicttests.cpp b/kmail/tests/messagedicttests.cpp
index cdb24f6d..4565f10c 100644
--- a/kmail/tests/messagedicttests.cpp
+++ b/kmail/tests/messagedicttests.cpp
@@ -4,10 +4,10 @@
*/
#include <kdebug.h>
-#include <kunittest/runner.h>
-#include <kunittest/module.h>
+#include <tdeunittest/runner.h>
+#include <tdeunittest/module.h>
-#include "kmdict.h"
+#include "tdemdict.h"
#include "messagedicttests.h"
diff --git a/kmail/tests/messagedicttests.h b/kmail/tests/messagedicttests.h
index abff55da..f60a3b2f 100644
--- a/kmail/tests/messagedicttests.h
+++ b/kmail/tests/messagedicttests.h
@@ -7,7 +7,7 @@
#ifndef MESSAGEDICTTESTS_H
#define MESSAGEDICTTESTS_H
-#include <kunittest/tester.h>
+#include <tdeunittest/tester.h>
class KMDict;
diff --git a/kmail/tests/mimelibtests.h b/kmail/tests/mimelibtests.h
index 0f503324..8fd06124 100644
--- a/kmail/tests/mimelibtests.h
+++ b/kmail/tests/mimelibtests.h
@@ -20,7 +20,7 @@
#ifndef MIMELIBTEST_H
#define MIMELIBTEST_H
-#include <kunittest/tester.h>
+#include <tdeunittest/tester.h>
class DwString;
class MimeLibTester : public KUnitTest::SlotTester
diff --git a/kmail/tests/storagelayermodule.cpp b/kmail/tests/storagelayermodule.cpp
index 91362471..fcfb884e 100644
--- a/kmail/tests/storagelayermodule.cpp
+++ b/kmail/tests/storagelayermodule.cpp
@@ -5,12 +5,12 @@
* have to fix it" license.
*/
-#include <kunittest/runner.h>
-#include <kunittest/module.h>
+#include <tdeunittest/runner.h>
+#include <tdeunittest/module.h>
#include "messagedicttests.h"
using namespace KUnitTest;
-KUNITTEST_MODULE( kunittest_storagelayermodule, "KMail Storage Layer Tests" );
+KUNITTEST_MODULE( tdeunittest_storagelayermodule, "KMail Storage Layer Tests" );
KUNITTEST_MODULE_REGISTER_TESTER( MessageDictTester );
diff --git a/kmail/tests/utiltests.cpp b/kmail/tests/utiltests.cpp
index d0b3135b..936cc3ab 100644
--- a/kmail/tests/utiltests.cpp
+++ b/kmail/tests/utiltests.cpp
@@ -4,13 +4,13 @@
*/
#include <kdebug.h>
-#include <kunittest/runner.h>
-#include <kunittest/module.h>
+#include <tdeunittest/runner.h>
+#include <tdeunittest/module.h>
#include "utiltests.h"
using namespace KUnitTest;
-KUNITTEST_MODULE( kunittest_utilmodule, "KMail::Util Tests" );
+KUNITTEST_MODULE( tdeunittest_utilmodule, "KMail::Util Tests" );
KUNITTEST_MODULE_REGISTER_TESTER( UtilTester );
#include "util.h"
diff --git a/kmail/tests/utiltests.h b/kmail/tests/utiltests.h
index b2cb8c69..0bcbcdf1 100644
--- a/kmail/tests/utiltests.h
+++ b/kmail/tests/utiltests.h
@@ -7,7 +7,7 @@
#ifndef UTILTESTS_H
#define UTILTESTS_H
-#include <kunittest/tester.h>
+#include <tdeunittest/tester.h>
class UtilTester : public KUnitTest::SlotTester
{
diff --git a/kmail/urlhandlermanager.cpp b/kmail/urlhandlermanager.cpp
index 8e72b8ab..65c18d73 100644
--- a/kmail/urlhandlermanager.cpp
+++ b/kmail/urlhandlermanager.cpp
@@ -47,7 +47,7 @@
#include <kstandarddirs.h>
#include <kurldrag.h>
-#include <kimproxy.h>
+#include <tdeimproxy.h>
#include <kurl.h>
#include <algorithm>
@@ -399,7 +399,7 @@ TQString KMail::URLHandlerManager::statusBarMessage( const KURL & url, KMReaderW
#include <klocale.h>
#include <kprocess.h>
#include <kmessagebox.h>
-#include <khtml_part.h>
+#include <tdehtml_part.h>
#include <tqstring.h>
diff --git a/kmail/tests/mimelibtests.cpp b/kmail/tests/mimelibtests.cpp
index 6f4cf189..e1162093 100644
--- a/kmail/tests/mimelibtests.cpp
+++ b/kmail/tests/mimelibtests.cpp
@@ -21,12 +21,12 @@
#include "mimelibtests.moc"
#include <kdebug.h>
-#include <kunittest/runner.h>
-#include <kunittest/module.h>
+#include <tdeunittest/runner.h>
+#include <tdeunittest/module.h>
using namespace KUnitTest;
-KUNITTEST_MODULE( kunittest_mimelibmodule, "Mimelib Tests" );
+KUNITTEST_MODULE( tdeunittest_mimelibmodule, "Mimelib Tests" );
KUNITTEST_MODULE_REGISTER_TESTER( MimeLibTester );
#include <mimelib/string.h>
@@ -56,7 +56,7 @@ static TQString makePrintable( const DwString& str )
TQCString MimeLibTester::readFile(const TQString& fileName)
{
TQFile file( fileName );
// #!@#$& kunittest... VERIFY() does nothing in setUp. Using assert instead.
bool ok = file.open( IO_ReadOnly );
if ( !ok ) {
kdError() << fileName << " not found!" << endl;
@@ -56,7 +56,7 @@ static TQString makePrintable( const DwString& str )
{
TQFile file( fileName );
- // #!@#$& kunittest... VERIFY() does nothing in setUp. Using assert instead.
+ // #!@#$& tdeunittest... VERIFY() does nothing in setUp. Using assert instead.
bool ok = file.open( IO_ReadOnly );
if ( !ok ) {